@@ -43,15 +43,44 @@ from .constants import band_names, band_color, band_min_freq, band_max_freq, \
 # Setup Functions
 ##############################################
 
-def _set_service():
-    """Set the url for the ALMA TAP service."""
-    service = tap.TAPService("https://almascience.eso.org/tap")
+def _set_service(tap_service='ESO'):
+    """
+    Set the url for the ALMA TAP service.
+
+    Parameters
+    ----------
+    tap_service : str, optional
+         (Default value = 'ESO')
+         The TAP service to use. Options are:
+         'ESO' for Europe (https://almascience.eso.org/tap),
+         'NRAO' for North America (https://almascience.nrao.edu/tap), or
+         'NAOJ' for East Asia (https://almascience.nrao.edu/tap)
+
+    """
+    if tap_service == 'NRAO':
+        service = tap.TAPService("https://almascience.nrao.edu/tap")
+    elif tap_service == 'NAOJ':
+        service = tap.TAPService("https://almascience.nao.ac.jp/tap")
+    else:
+        service = tap.TAPService("https://almascience.eso.org/tap")
     return service
 
 
-def _get_metadata():
-    """Get TAP metadata in order to set units properly."""
-    service = _set_service()
+def _get_metadata(tap_service='ESO'):
+    """
+    Get TAP metadata in order to set units properly.
+
+    Parameters
+    ----------
+    tap_service : str, optional
+         (Default value = 'ESO')
+         The TAP service to use. Options are:
+         'ESO' for Europe (https://almascience.eso.org/tap),
+         'NRAO' for North America (https://almascience.nrao.edu/tap), or
+         'NAOJ' for East Asia (https://almascience.nao.ac.jp/tap)
+
+    """
+    service = _set_service(tap_service)
     metadata_query = "SELECT column_name, datatype, unit, ucd, utype, description from TAP_SCHEMA.columns"
     TAP_metadata = service.search(metadata_query)
     return pd.DataFrame(TAP_metadata).set_index('column_name')
@@ -61,7 +90,7 @@ def _get_metadata():
 # Query Functions
 ##############################################
 
-def conesearch(ra, dec, search_radius=1., point=True, public=True, published=None, print_targets=True,
+def conesearch(ra, dec, search_radius=1., tap_service='ESO', point=False, public=True, published=None, print_targets=True,
                print_query=False):
     """
     Query the ALMA archive for a given position and radius around it.
@@ -75,12 +104,17 @@ def conesearch(ra, dec, search_radius=1., point=True, public=True, published=Non
     search_radius : float, optional
          (Default value = 1. arcmin)
          Search radius (in arcmin) around the source coordinates.
+    tap_service : str, optional
+         (Default value = 'ESO')
+         The TAP service to use. Options are:
+         'ESO' for Europe (https://almascience.eso.org/tap),
+         'NRAO' for North America (https://almascience.nrao.edu/tap), or
+         'NAOJ' for East Asia (https://almascience.nao.ac.jp/tap)
     point : bool, optional
          (Default value = True)
-         Search whether the phase center of the observations is contained within the search_radius (point=True)
-         or whether any part of the observed region overlaps with the cone extending the search_radius (point=False).
-         Note that point=True is much faster than point=False but the latter should be used if one is interested in
-         searching for mosaics.
+         Search whether the specified position (ra, dec) is contained within any ALMA observations (point=True)
+         or query all ALMA observations that overlap with a cone centred at the specified position (ra, dec) and
+         extending the search_radius (point=False). In the case of point=True, the search_radius parameter is ignored.
     public : bool, optional
          (Default value = True)
          Search for public data (public=True), proprietary data (public=False),
@@ -103,11 +137,10 @@ def conesearch(ra, dec, search_radius=1., point=True, public=True, published=Non
     """
     search_radius = search_radius * u.arcmin
     if point:
-        query = "SELECT * FROM ivoa.obscore WHERE 1 = CONTAINS(POINT('ICRS', s_ra, s_dec), " \
-                "CIRCLE('ICRS',{},{},{}))".format(ra, dec, search_radius.to(u.deg).value)
+        query = "SELECT * FROM ivoa.ObsCore WHERE 1 = CONTAINS(POINT('ICRS',{},{}), s_region)".format(ra, dec)
     else:
-        query = "SELECT * FROM ivoa.ObsCore WHERE 1 = INTERSECTS(CIRCLE('ICRS',{},{},{}), " \
-                "s_region)".format(ra, dec, search_radius.to(u.deg).value)
+        query = "SELECT * FROM ivoa.ObsCore WHERE (1 = INTERSECTS(CIRCLE('ICRS',{},{},{}), s_region) OR " \
+                "1 = CONTAINS(POINT('ICRS',{},{}), s_region))".format(ra, dec, search_radius.to(u.deg).value, ra, dec)
 
     if public:
         query = "{} AND data_rights LIKE '%Public%'".format(query)
@@ -117,7 +150,7 @@ def conesearch(ra, dec, search_radius=1., point=True, public=True, published=Non
     if print_query:
         print("Your query is: {}".format(query))
 
-    TAP_df = run_query(query)
+    TAP_df = run_query(query, tap_service=tap_service)
     if TAP_df is not None:
         if published:  # case pf published = True
             TAP_df = TAP_df[TAP_df['publication_year'].notnull()]
@@ -127,7 +160,7 @@ def conesearch(ra, dec, search_radius=1., point=True, public=True, published=Non
         return filtered_df
 
 
-def run_query(query_str):
+def run_query(query_str, tap_service='ESO'):
     """
     Run the TAP query through PyVO service.
 
@@ -135,13 +168,18 @@ def run_query(query_str):
     ----------
     query_str : str
          ADQL query to send to the PyVO TAP service
-
+    tap_service : str, optional
+         (Default value = 'ESO')
+         The TAP service to use. Options are:
+         'ESO' for Europe (https://almascience.eso.org/tap),
+         'NRAO' for North America (https://almascience.nrao.edu/tap), or
+         'NAOJ' for East Asia (https://almascience.nao.ac.jp/tap)
     Returns
     -------
     pandas.DataFrame containing the query results
 
     """
-    service = _set_service()
+    service = _set_service(tap_service)
     # Run query
     pyvo_TAP_results = service.search(query_str)  # for large queries add maxrec=1000000
     # Transform output into astropy table first, then to a pandas DataFrame
@@ -151,7 +189,8 @@ def run_query(query_str):
     return TAP_df
 
 
-def target(sources, search_radius=1., point=True, public=True, published=None, print_query=False, print_targets=True):
+def target(sources, search_radius=1., tap_service='ESO', point=False, public=True, published=None, print_query=False,
+           print_targets=True):
     """
     Query targets by name.
 
@@ -163,18 +202,23 @@ def target(sources, search_radius=1., point=True, public=True, published=None, p
 
     Parameters
     ----------
-    sources : list of str
+    sources : str or list of str
          list of sources by name.
          (IMPORTANT: source names must be identified by at least one of Simbad, NED, or Vizier)
     search_radius : float, optional
          (Default value = 1. arcmin)
          Search radius (in arcmin) around the source coordinates.
+    tap_service : str, optional
+         (Default value = 'ESO')
+         The TAP service to use. Options are:
+         'ESO' for Europe (https://almascience.eso.org/tap),
+         'NRAO' for North America (https://almascience.nrao.edu/tap), or
+         'NAOJ' for East Asia (https://almascience.nao.ac.jp/tap)
     point : bool, optional
          (Default value = True)
-         Search whether the phase center of the observations is contained within the search_radius (point=True)
-         or whether any part of the observed region overlaps with the cone extending the search_radius (point=False).
-         Note that point=True is much faster than point=False but the latter should be used if one is interested in
-         searching for mosaics.
+         Search whether the specified position (ra, dec) is contained within any ALMA observations (point=True)
+         or query all ALMA observations that overlap with a cone centred at the specified position (ra, dec) and
+         extending the search_radius (point=False). In the case of point=True, the search_radius parameter is ignored.
     public : bool, optional
          (Default value = True)
          Search for public data (public=True), proprietary data (public=False),
@@ -199,6 +243,8 @@ def target(sources, search_radius=1., point=True, public=True, published=None, p
     keysearch : Query the ALMA archive for any (string-type) keywords defined in ALMA TAP system.
 
     """
+    if isinstance(sources, str):
+        sources = [sources]
     print("================================")
     print("alminer.target results ")
     print("================================")
@@ -210,8 +256,8 @@ def target(sources, search_radius=1., point=True, public=True, published=None, p
             # Get source coodinates from astropy SESAME resolver querying multiple databases (SIMBAD, NED, Vizier)
             source_pos = get_icrs_coordinates(s)
             TAP_df = conesearch(ra=source_pos.ra.deg, dec=source_pos.dec.deg, search_radius=search_radius,
-                                point=point, public=public, published=published, print_query=print_query,
-                                print_targets=print_targets)
+                                tap_service=tap_service, point=point, public=public, published=published,
+                                print_query=print_query, print_targets=print_targets)
             if TAP_df is not None:
                 complete_results.append(TAP_df)
         except name_resolve.NameResolveError as err:  # source coords not found in SESAME resolver
@@ -230,8 +276,8 @@ def target(sources, search_radius=1., point=True, public=True, published=None, p
         print("--------------------------------")
 
 
-def catalog(target_df, search_radius=1., point=True, public=True, published=None, print_query=False,
-            print_targets=True):
+def catalog(target_df, search_radius=1., tap_service='ESO', point=False, public=True, published=None,
+            print_query=False, print_targets=True):
     """
     Query the ALMA archive for a list of coordinates or a catalog of sources based on their coordinates.
 
@@ -249,12 +295,17 @@ def catalog(target_df, search_radius=1., point=True, public=True, published=None
     search_radius : float, optional
          (Default value = 1. arcmin)
          Search radius (in arcmin) around the source coordinates.
+    tap_service : str, optional
+         (Default value = 'ESO')
+         The TAP service to use. Options are:
+         'ESO' for Europe (https://almascience.eso.org/tap),
+         'NRAO' for North America (https://almascience.nrao.edu/tap), or
+         'NAOJ' for East Asia (https://almascience.nao.ac.jp/tap)
     point : bool, optional
          (Default value = True)
-         Search whether the phase center of the observations is contained within the search_radius (point=True)
-         or whether any part of the observed region overlaps with the cone extending the search_radius (point=False).
-         Note that point=True is much faster than point=False but the latter should be used if one is interested in
-         searching for mosaics.
+         Search whether the specified position (ra, dec) is contained within any ALMA observations (point=True)
+         or query all ALMA observations that overlap with a cone centred at the specified position (ra, dec) and
+         extending the search_radius (point=False). In the case of point=True, the search_radius parameter is ignored.
     public : bool, optional
          (Default value = True)
          Search for public data (public=True), proprietary data (public=False),
@@ -283,8 +334,8 @@ def catalog(target_df, search_radius=1., point=True, public=True, published=None
         print("Target = {}".format(target_df.Name[p]))
         source_pos = SkyCoord(target_df.RAJ2000[p] * u.deg, target_df.DEJ2000[p] * u.deg, frame='icrs')
         TAP_df = conesearch(ra=source_pos.ra.deg, dec=source_pos.dec.deg, search_radius=search_radius,
-                            point=point, public=public, published=published, print_query=print_query,
-                            print_targets=print_targets)
+                            tap_service=tap_service, point=point, public=public, published=published,
+                            print_query=print_query, print_targets=print_targets)
         if TAP_df is not None:
             complete_results.append(TAP_df)
     # if the list of query results is not empty, concatenate them together into one DataFrame
@@ -298,7 +349,7 @@ def catalog(target_df, search_radius=1., point=True, public=True, published=None
         print("--------------------------------")
 
 
-def keysearch(search_dict, public=True, published=None, print_query=False, print_targets=True):
+def keysearch(search_dict, tap_service='ESO', public=True, published=None, print_query=False, print_targets=True):
     """
     Query the ALMA archive for any (string-type) keywords defined in ALMA TAP system.
 
@@ -307,6 +358,12 @@ def keysearch(search_dict, public=True, published=None, print_query=False, print
     search_dict : dict[str, list of str]
          Dictionary of keywords in the ALMA archive and their values. Values must be formatted as a list.
          A list of valid keywords are stored in VALID_KEYWORDS_STR variable.
+    tap_service : str, optional
+         (Default value = 'ESO')
+         The TAP service to use. Options are:
+         'ESO' for Europe (https://almascience.eso.org/tap),
+         'NRAO' for North America (https://almascience.nrao.edu/tap), or
+         'NAOJ' for East Asia (https://almascience.nao.ac.jp/tap)
     public : bool, optional
          (Default value = True)
          Search for public data (public=True), proprietary data (public=False),
@@ -330,8 +387,9 @@ def keysearch(search_dict, public=True, published=None, print_query=False, print
     -----
     The power of this function is in combining keywords. When multiple keywords are provided, they are
     queried using 'AND' logic, but when multiple values are provided for a given keyword, they are queried using
-    'OR' logic. If a given value contains spaces, its constituents are queried using 'AND' logic. The only exception
-    to this rule is the 'target_name' keyword.
+    'OR' logic. If a given value contains spaces, its constituents are queried using 'AND' logic. Words encapsulated
+     in quotation marks (either ' or ") are queried as phrases. Values for the 'target_name' keyword
+     are queried with 'OR' logic.
 
     Examples
     --------
@@ -343,9 +401,13 @@ def keysearch(search_dict, public=True, published=None, print_query=False, print
          will query the archive for projects with the words
          "high-mass" OR "star" OR "formation" OR "outflow" OR "disk" in their proposal abstracts.
 
-    keysearch({"proposal_abstract": ["star formation"], "scientific_category":['Galaxies']})
-         will query the archive for projects with the words
-         "star" AND "formation" in their proposal abstracts AND
+    keysearch({"proposal_abstract": ["'high-mass star formation' outflow disk"]})
+         will query the archive for projects with the phrase
+         "high-mass star formation" AND the words "outflow" AND "disk" in their proposal abstracts.
+
+    keysearch({"proposal_abstract": ["'star formation'"], "scientific_category":['Galaxies']})
+         will query the archive for projects with the phrase
+         "star formation" in their proposal abstracts AND
          projects that are within the scientific_category of 'Galaxies'.
 
     """
@@ -378,10 +440,12 @@ def keysearch(search_dict, public=True, published=None, print_query=False, print
         else:
             keyword_query_list = []
             for v in values:
-                # If there are spaces in the values of a given keyword, split them out and query them with AND logic
+                # If there are quotations in the values of a given keyword, split them out and query them as phrases
+                # If there are remaining keywords separated by spaces, split them out and query them with AND logic
                 if re.search(r"\s", v):
-                    split_values = v.split()
-                    current_query = ["LOWER({}) LIKE '%{}%'".format(keyword, s.lower()) for s in split_values]
+                    split_values = re.findall(r"['\"].*['\"]|\d+\.\d+|[\w-]+", v)
+                    current_query = ["LOWER({}) LIKE '%{}%'".format(keyword, re.sub("['\"]", '', s.lower())) for s in
+                                     split_values]
                     keyword_query_list.append("({})".format(" AND ".join(current_query)))
                 # If separate words are provided as values, query them with OR logic
                 else:
@@ -391,7 +455,7 @@ def keysearch(search_dict, public=True, published=None, print_query=False, print
     full_query = "SELECT * FROM ivoa.obscore WHERE {} ORDER BY proposal_id".format(" AND ".join(full_query_list))
     if print_query:
         print("Your query is: {}".format(full_query))
-    TAP_df = run_query(full_query)
+    TAP_df = run_query(full_query, tap_service=tap_service)
     # Filter whether the user wants published data, unpublished data, or both (default)
     if published:  # case pf published = True
         TAP_df = TAP_df[TAP_df['publication_year'].notnull()]
@@ -428,6 +492,17 @@ def _set_plot_params(ax, title, xlabel, ylabel, legend=True, log=False):
         ax.set_ylim(ymin=1e-1)
 
 
+def _format_bytes(size):
+    """Convert the size of the dota to be downloaded in human-readable format."""
+    power = 1000
+    n = 0
+    power_labels = {0 : 'B', 1: 'KB', 2: 'MB', 3: 'GB', 4: 'TB', 5: 'PB', 6: 'EB'}
+    while size > power:
+        size /= power
+        n += 1
+    return size, power_labels[n]
+
+
 def filter_results(TAP_df, print_targets=True):
     """
     Add a few new useful columns to the pandas.DataFrame with the query results from the PyVO TAP service and
@@ -565,7 +640,7 @@ def explore(observations, allcols=False, allrows=False):
     if not allcols:
         observations = observations.iloc[:, : len(NEW_COLUMNS)]
     return observations
-    
+
 
 def get_units(column):
     """Print the units for a given column in the query results DataFrame."""
@@ -879,6 +954,7 @@ def plot_overview(observations, mark_freq='', z=0., mark_CO=False, showfig=True,
 
         fig.tight_layout()
         plt.rcParams['figure.dpi'] = 300
+        plt.rcParams['figure.facecolor'] = 'white'
         _save_plot(savefig)
         if showfig:
             plt.show()
@@ -963,6 +1039,7 @@ def plot_bands(observations, mark_freq='', z=0., mark_CO=False, showfig=True, sa
 
         plt.tight_layout()
         plt.rcParams['figure.dpi'] = 300
+        plt.rcParams['figure.facecolor'] = 'white'
         _save_plot(savefig)
         if showfig:
             plt.show()
@@ -971,7 +1048,7 @@ def plot_bands(observations, mark_freq='', z=0., mark_CO=False, showfig=True, sa
         print("--------------------------------")
         print("Nothing to plot: the DataFrame provided is empty.")
         print("--------------------------------")
-    
+
 
 def plot_observations(observations, mark_freq='', z=0., mark_CO=False, showfig=True, savefig=None):
     """
@@ -1031,6 +1108,7 @@ def plot_observations(observations, mark_freq='', z=0., mark_CO=False, showfig=T
 
         plt.tight_layout()
         plt.rcParams['figure.dpi'] = 300
+        plt.rcParams['figure.facecolor'] = 'white'
         _save_plot(savefig)
         if showfig:
             plt.show()
@@ -1148,6 +1226,7 @@ def plot_line_overview(observations, line_freq, z=0., line_name='', showfig=True
 
         plt.tight_layout()
         plt.rcParams['figure.dpi'] = 300
+        plt.rcParams['figure.facecolor'] = 'white'
         _save_plot(savefig)
         if showfig:
             plt.show()
@@ -1186,6 +1265,7 @@ def plot_sky(observations, showfig=True, savefig=None):
     ax.scatter(ra.radian, dec.radian, color="#E5323B", zorder=2)
     ax.set_title("Sky distribution", fontsize=18)
     plt.rcParams['figure.dpi'] = 300
+    plt.rcParams['figure.facecolor'] = 'white'
     _save_plot(savefig)
     if showfig:
         plt.show()
@@ -1270,7 +1350,7 @@ def save_source_reports(observations, mark_freq='', z=0., mark_CO=False):
 ##############################################
 
 def download_data(observations, fitsonly=False, dryrun=False, print_urls=False, filename_must_include='',
-                  location='./data'):
+                  location='./data', archive_mirror='ESO'):
     """
     Download ALMA data from the archive to a location on the local machine.
 
@@ -1299,6 +1379,12 @@ def download_data(observations, fitsonly=False, dryrun=False, print_urls=False,
     location : str, optional
          (Default value = ./data)
          directory where the downloaded data should be placed.
+    archive_mirror : str, optional
+         (Default value = 'ESO')
+         The archive service to use. Options are:
+         'ESO' for Europe (https://almascience.eso.org),
+         'NRAO' for North America (https://almascience.nrao.edu), or
+         'NAOJ' for East Asia (https://almascience.nao.ac.jp)
 
     """
     print("================================")
@@ -1306,6 +1392,13 @@ def download_data(observations, fitsonly=False, dryrun=False, print_urls=False,
     myAlma = Alma()
     default_location = './data'
     myAlma.cache_location = default_location
+    if archive_mirror == 'NRAO':
+        mirror = "https://almascience.nrao.edu"
+    elif archive_mirror == 'NAOJ':
+        mirror = "https://almascience.nao.ac.jp"
+    else:
+        mirror = "https://almascience.eso.org"
+    myAlma.archive_url = mirror
     # catch the case where the DataFrame is empty.
     try:
         if any(observations['data_rights'] == 'Proprietary'):
@@ -1323,55 +1416,62 @@ def download_data(observations, fitsonly=False, dryrun=False, print_urls=False,
     except TypeError:
         print("No data to download. Check the input DataFrame.")
         return
-    # change download location if specified by user, else the location will be the astrquery cache location
+    # change download location if specified by user, else the location will be a folder called 'data'
+    # in the current working directory
     if location != default_location:
         if os.path.isdir(location):
             myAlma.cache_location = location
         else:
             print("{} is not a directory. The download location will be set to {}".format(location, default_location))
             myAlma.cache_location = default_location
+    elif (location == default_location) and not os.path.isdir(location):  # create the 'data' subdirectory
+        os.makedirs(default_location)
     if fitsonly:
-        data_table = Alma.get_data_info(uids_list, expand_tarfiles=True)
+        data_table = myAlma.get_data_info(uids_list, expand_tarfiles=True)
         # filter the data_table and keep only rows with "fits" in 'access_url' and the strings provided by user
         # in 'filename_must_include' parameter
         dl_table = data_table[[i for i, v in enumerate(data_table['access_url']) if v.endswith(".fits") and
                                all(i in v for i in filename_must_include)]]
-        dl_link_list = dl_table['access_url'].tolist()
-        # keep track of the download size and number of files to download
-        dl_size = dl_table['content_length'].sum() / 1E9
-        dl_files = len(dl_table)
-        if dryrun:
-            print("This is a dryrun. To begin download, set dryrun=False.")
-            print("================================")
-        else:
-            print("Starting download. Please wait...")
-            print("================================")
+    else:
+        data_table = myAlma.get_data_info(uids_list, expand_tarfiles=False)
+        # filter the data_table and keep only rows with "fits" in 'access_url' and the strings provided by user
+        # in 'filename_must_include' parameter
+        dl_table = data_table[[i for i, v in enumerate(data_table['access_url']) if
+                               all(i in v for i in filename_must_include)]]
+    dl_df = dl_table.to_pandas()
+    # remove empty elements in the access_url column
+    dl_df = dl_df.loc[dl_df.access_url != '']
+    dl_link_list = list(dl_df['access_url'].unique())
+    # keep track of the download size and number of files to download
+    dl_size = dl_df['content_length'].sum()
+    dl_files = len(dl_df['access_url'].unique())
+    dl_uid_list = list(dl_df['ID'].unique())
+    if dryrun:
+        print("This is a dryrun. To begin download, set dryrun=False.")
+        print("================================")
+    else:
+        print("Starting download. Please wait...")
+        print("================================")
+        try:
             myAlma.download_files(dl_link_list, cache=True)
+        except ValueError as e:
+            print(e)
+    if dl_files > 0:
+        print("Download location = {}".format(myAlma.cache_location))
+        print("Total number of Member OUSs to download = {}".format(len(dl_uid_list)))
+        print("Selected Member OUSs: {}".format(dl_uid_list))
+        print("Number of files to download = {}".format(dl_files))
+        dl_size_fmt, dl_format = _format_bytes(dl_size)
+        print("Needed disk space = {:.1f} {}".format(dl_size_fmt, dl_format))
+        if print_urls:
+            print("File URLs to download = {}".format("\n".join(dl_link_list)))
     else:
-        data_table = Alma.get_data_info(uids_list, expand_tarfiles=False)
-        dl_link_list = data_table['access_url'].tolist()
-        # keep track of the download size and number of files to download
-        dl_size = data_table['content_length'].sum() / 1E9
-        dl_files = len(data_table)
-        if dryrun:
-            print("This is a dryrun. To begin download, set dryrun=False.")
-            print("================================")
-        else:
-            print("Starting download. Please wait...")
-            print("================================")
-            myAlma.retrieve_data_from_uid(uids_list, cache=True)
-    print("Download location = {}".format(myAlma.cache_location))
-    print("Total number of Member OUSs to download = {}".format(len(uids_list)))
-    print("Selected Member OUSs: {}".format(uids_list.tolist()))
-    print("Number of files to download = {}".format(dl_files))
-    if dl_size > 1000.:
-        print("Needed disk space = {:.1f} TB".format(dl_size/1000.))
-    elif dl_size < 1.:
-        print("Needed disk space = {:.1f} MB".format(dl_size*1000.))
-    else:
-        print("Needed disk space = {:.1f} GB".format(dl_size))
-    if print_urls:
-        print("File URLs to download = {}".format("\n".join(dl_link_list)))
+        print("Nothing to download.")
+        print("Note: often only a subset of the observations (e.g. the representative window) is ingested into "
+              "the archive. In such cases, you may need to download the raw dataset, reproduce the calibrated "
+              "measurement set, and image the observations of interest. It is also possible to request calibrated "
+              "measurement sets through a Helpdesk ticket to the European ARC "
+              "(see https://almascience.eso.org/local-news/requesting-calibrated-measurement-sets-in-europe).")
     print("--------------------------------")
 
 ####################################################################
